exceptions - Infernet ML
Description: Infernet ML Documentation

Skip to content

# Module: `exceptions`

## `APIKeyMissingException`

Bases: `InfernetMLException`

Exception for when an API key is missing

Source code in `src/infernet_ml/workflows/exceptions.py`

    21
    22
    23
    24
    class APIKeyMissingException(InfernetMLException):
        """Exception for when an API key is missing"""

        pass

## `InfernetMLException`

Bases: `Exception`

Base exception for all infernet_ml exceptions

Source code in `src/infernet_ml/workflows/exceptions.py`

    15
    16
    17
    18
    class InfernetMLException(Exception):
        """Base exception for all infernet_ml exceptions"""

        pass

## `RetryableException`

Bases: `Exception`

Marker exception that should be thrown when it can be retried

Source code in `src/infernet_ml/workflows/exceptions.py`

    1
    2
    3
    4
    class RetryableException(Exception):
        """Marker exception that should be thrown when it can be retried"""

        pass

## `ServiceException`

Bases: `Exception`

Marker exception for service specific exceptions that should be thrown. Use RetryableException if the exception can be retried

Source code in `src/infernet_ml/workflows/exceptions.py`

     7
     8
     9
    10
    11
    12
    class ServiceException(Exception):
        """Marker exception for service specific exceptions that should
        be thrown. Use RetryableException if the exception can be retried
        """

        pass